import fs from 'fs';
import path from 'path';
/**
 * Attempt to find migrations directory.
 *
 * Checks for the following directories in order:
 * - `migrationDir` argument from Payload config
 * - `src/migrations`
 * - `dist/migrations`
 * - `migrations`
 *
 * Defaults to `src/migrations`
 *
 * @param migrationDir
 * @returns
 */ export function findMigrationDir(migrationDir) {
    const cwd = process.cwd();
    const srcDir = path.resolve(cwd, 'src/migrations');
    const distDir = path.resolve(cwd, 'dist/migrations');
    const relativeMigrations = path.resolve(cwd, 'migrations');
    // Use arg if provided
    if (migrationDir) {
        return migrationDir;
    }
    // Check other common locations
    if (fs.existsSync(srcDir)) {
        return srcDir;
    }
    if (fs.existsSync(distDir)) {
        return distDir;
    }
    if (fs.existsSync(relativeMigrations)) {
        return relativeMigrations;
    }
    return srcDir;
}

//# sourceMappingURL=findMigrationDir.js.map